@@ -13,6 +13,7 @@ from inspect import signature
 from dacite import from_dict, Config
 
 from grongier.pex._common import _Common
+from grongier.pex._utils import _Utils
 
 class _BusinessHost(_Common):
     """ This is a superclass for BusinessService, BusinesProcess, and BusinessOperation that
@@ -30,9 +31,13 @@ class _BusinessHost(_Common):
         :return: The function dispatch_serializer is being returned.
         """
         def dispatch_serializer(self,*params, **param2):
+            # Handle positional arguments
             serialized=[]
             for param in params:
                 serialized.append(self._dispatch_serializer(param))
+            # Handle keyword arguments
+            for key, value in param2.items():
+                param2[key] = self._dispatch_serializer(value)
             return fonction(self,*serialized, **param2)
         return dispatch_serializer
 
@@ -59,9 +64,13 @@ class _BusinessHost(_Common):
         :return: The function dispatch_deserializer is being returned.
         """
         def dispatch_deserializer(self,*params, **param2):
+            # Handle positional arguments
             serialized=[]
             for param in params:
-                serialized.append(self._dispatch_deserializer(param))
+                serialized.append(self._dispatch_serializer(param))
+            # Handle keyword arguments
+            for key, value in param2.items():
+                param2[key] = self._dispatch_serializer(value)
             return fonction(self,*serialized, **param2)
         return dispatch_deserializer
 
@@ -131,11 +140,7 @@ class _BusinessHost(_Common):
         msg = iris.cls('Grongier.PEX.PickleMessage')._New()
         msg.classname = module + "." + classname
 
-        stream = iris.cls('%Stream.GlobalCharacter')._New()
-        n = self.buffer
-        chunks = [pickle_string[i:i+n] for i in range(0, len(pickle_string), n)]
-        for chunk in chunks:
-            stream.Write(chunk)
+        stream = _Utils.string_to_stream(pickle_string)
         msg.jstr = stream
 
         return msg
@@ -169,49 +174,24 @@ class _BusinessHost(_Common):
         Returns:
         string: The message in json format.
         """
-        json_string = json.dumps(message, cls=IrisJSONEncoder)
+        json_string = json.dumps(message, cls=IrisJSONEncoder, ensure_ascii=False)
         module = message.__class__.__module__
         classname = message.__class__.__name__
 
         msg = iris.cls('Grongier.PEX.Message')._New()
         msg.classname = module + "." + classname
 
-        stream = iris.cls('%Stream.GlobalCharacter')._New()
-        n = self.buffer
-        chunks = [json_string[i:i+n] for i in range(0, len(json_string), n)]
-        for chunk in chunks:
-            stream.Write(chunk)
+        stream = _Utils.string_to_stream(json_string)
         msg.jstr = stream
 
         return msg
 
-
-    def _serialize(self,message):
-        """ Converts a message into json format.
-
-        Parameters:
-        message: The message to serialize, an instance of a class that is a subclass of Message.
-
-        Returns:
-        string: The message in json format.
-        """
-        if (message is not None):
-            json_string = json.dumps(message, cls=IrisJSONEncoder)
-            module = message.__class__.__module__
-            classname = message.__class__.__name__
-            return  module + "." + classname + ":" + json_string
-        else:
-            return None
-
     def _deserialize_pickle_message(self,serial):
         """ 
         Converts an iris grongier.pex.message into an python dataclass message.
         
         """
-        string = ""
-        serial.jstr.Rewind()
-        while not serial.jstr.AtEnd:
-            string += serial.jstr.Read(self.buffer)
+        string = _Utils.stream_to_string(serial.jstr)
 
         msg = pickle.loads(codecs.decode(string.encode(), "base64"))
         return msg
@@ -249,49 +229,12 @@ class _BusinessHost(_Common):
         except Exception:
             raise ImportError("Class not found: " + classname)
 
-        string = ""
-        serial.jstr.Rewind()
-        while not serial.jstr.AtEnd:
-            string += serial.jstr.Read(self.buffer)
+        string = _Utils.stream_to_string(serial.jstr)
 
         jdict = json.loads(string, cls=IrisJSONDecoder)
         msg = self._dataclass_from_dict(msg,jdict)
         return msg
 
-
-    def _deserialize(self,serial):
-        """ Converts a json string into a message of type classname, which is stored in the json string.
-
-        Parameters:
-        serial: The json string to deserialize.
-
-        Returns:
-        Message: The message as an instance of the class specified in the json string, which is a subclass of Message.
-
-        Raises:
-        ImportError: if the classname does not include a module name to import.
-        """
-        if (serial is not None and serial != ""):
-            i = serial.find(":")
-            if (i <=0):
-                raise ValueError("JSON message malformed, must include classname: " + serial)
-            classname = serial[:i]
-
-            j = classname.rindex(".")
-            if (j <=0):
-                raise ValueError("Classname must include a module: " + classname)
-
-            try:
-                module = importlib.import_module(classname[:j])
-                msg = getattr(module, classname[j+1:])
-            except Exception:
-                raise ImportError("Class not found: " + classname)
-            jdict = json.loads(serial[i+1:], cls=IrisJSONDecoder)
-            msg = self._dataclass_from_dict(msg,jdict)
-            return msg
-        else:
-            return None
-
     def _dataclass_from_dict(self,klass, dikt):
         """
         > If the field is not in the dataclass, then add it as an attribute
